"""IRModuleExample1, program to practice using the IRModule
Created Apr 30, 2018"""

"""
Copyright 2018 Owain Martin
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import RPi.GPIO as GPIO
import IRModule
import time

def remote_callback(code):        

    # Codes listed below are for the
    # SBC-IRC01 21 button remote by JOY-IT
    print(code)

    if code == 0xff30cf:
        print("1")
    elif code == 0xff18e7:
        print("2")
    elif code == 0xff7a85:
        print("3")
    elif code == 0xff10ef:
        print("4")
    elif code == 0xff38c7:
        print("5")
    elif code == 0xff5aa5:
        print("6")
    elif code == 0xff42bd:
        print("7")
    elif code == 0xff4ab5:
        print("8")
    elif code == 0xff52ad:
        print("9")
    elif code == 0xff6897:
        print("0")
    elif code == 0xff9867:
        print("ArrowDown/Next")
    elif code == 0xff02fd:
        print("ArrowUp/Prev")
    elif code == 0xffe01f:
        print("ArrowLeft/CH-")
    elif code == 0xff906f:
        print("ArrowRight/CH+")
    elif code == 0xffc23d:
        print("Stop/Mode")
    elif code == 0xff22dd:
        print("Setup")
    elif code == 0xffa25d:
        print("Vol-")
    elif code == 0xff629d:
        print("Play/Pause")
    elif code == 0xffe21d:
        print("Vol+")
    elif code == 0xffa857:
        print("Enter/Save")
    elif code == 0xffb04f:
        print("Return")
    else:
        print('UNKNOWN')  # unknown code
        
    print('--------------------')

    return

# set up IR pi pin and IR remote object
irPin = 16
ir = IRModule.IRRemote(callback='DECODE')

# set the value to 1 to get extra outputs
ExtraOutput = 0

# using 'DECODE' option for callback will print out
# the IR code received in hexadecimal
# this can be used to get the codes for whichever NEC
# compatable remote you are using

# set up GPIO options and set callback function required
# by the IR remote module (ir.pWidth)        
GPIO.setwarnings(False)
GPIO.setmode(GPIO.BCM)      # uses numbering outside circles
GPIO.setup(irPin,GPIO.IN)   # set irPin to input
GPIO.add_event_detect(irPin,GPIO.BOTH,callback=ir.pWidth)

print('Starting IR remote sensing using DECODE function and verbose setting equal True ')
print('Use ctrl-c to exit program')
print('--------------------------------------------------------------------------------')


try:

    if ExtraOutput == 1:
        ir.set_repeat(True)
        ir.set_verbose(True)
    
    # turn off verbose option and change the callback function
    # to the function created above - remote_callback()
    
    else:
        print('Turning off verbose and repeat setting and setting up callback')
        ir.set_repeat(False)
        ir.set_verbose(False)
        ir.set_callback(remote_callback)

    # This is where you could do other stuff
    # Blink a light, turn a motor, run a webserver
    # count sheep or mine bitcoin
    
    while True:
        time.sleep(1)

except:
    print('Removing callback and cleaning up GPIO')
    ir.remove_callback()
    GPIO.cleanup(irPin)
